Gemeinde Adressverwaltung GUI: Klassenhierarchie

Gemeinde Adressverwaltung GUI

Klassenhierarchie

gehe zur grafischen Darstellung der Klassenhierarchie

Die Liste der Ableitungen ist -mit Einschränkungen- alphabetisch sortiert:
[Detailebene 12]

▼CModell |
C Gemeinde_Modelle.Anrede |
C Gemeinde_Modelle.Familie |
C Gemeinde_Modelle.FamilieGruppe |
C Gemeinde_Modelle.FamilieGruppeSchlank |
C Gemeinde_Modelle.FamilieVersandart |
C Gemeinde_Modelle.FamilieVersandartSchlank |
C Gemeinde_Modelle.Farbe |
C Gemeinde_Modelle.Gemeinde |
C Gemeinde_Modelle.Gruppe |
C Gemeinde_Modelle.GruppeAnsprechpartner |
C Gemeinde_Modelle.Jobs | Modelle Anwendungsübergreifend (Regelmäßige Aufgaben, Länder usw.)
C Gemeinde_Modelle.JobsSchlank |
C Gemeinde_Modelle.Person |
C Gemeinde_Modelle.PersonGruppe |
C Gemeinde_Modelle.PersonGruppeSchlank |
C Gemeinde_Modelle.PersonSchlank |
C Gemeinde_Modelle.PersonVersandart |
C Gemeinde_Modelle.PersonVersandartSchlank |
C Gemeinde_Modelle.Versandart |
▼Ctk.Tk |
C Gemeinde.Login |
C Gemeinde.Main |